@@ -1,4 +1,4 @@
-from mpesa.api import Mpesa
+from mpesa import Mpesa
 
 PAYLOAD = {
     "ShortCode": "101010",
@@ -13,7 +13,6 @@ def test_register_url():
     response = register_url.register_url(PAYLOAD)
     if response:
         print("Response:", response)
-       
 
 if __name__ == "__main__":
     test_register_url(test_register_url())
